#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-FRZL5Mxbhg3DowIKsfGU3c
key:                  persistent-test-2.13.1.3-FRZL5Mxbhg3DowIKsfGU3c
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  fc71fe715ee9ff56fe8131fb71fcc79c
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-FRZL5Mxbhg3DowIKsfGU3c
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-E7cfXUQH5j0nG0YUtYjiD
    aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY base-4.18.2.1
    blaze-html-0.9.2.0-2DuDW300GIs3GBNnqFMort bytestring-0.11.5.3
    conduit-1.3.6.1-ASxyqnNN5o6JNEZENxLkTo containers-0.6.7
    exceptions-0.10.7 hspec-2.11.5-LAcpW14V5x92DJUdeVnlb
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-CJUbo8USfIGIxr2jPr9lYy
    monad-control-1.0.3.1-Ah73ESKiH1C3ayLrCvcag3
    monad-logger-0.3.42-3AUHQRnYPjtKVXOBqlK2pS mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-2JzkpZSkuF16uVA2fJmQDR
    quickcheck-instances-0.3.33-HPv8RpBuj5JGX3agFBow6
    random-1.2.1.3-Fpl3dUa1VuLH6jaWIu29Ly
    resourcet-1.2.6-1xyvvIMDXXY2PZlggmi6VN text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-H3Xr0tWobACCsfNTOUOwJB
    unliftio-0.2.25.1-7sXhGHm93AhzYdedcIgQ6
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

